@@ -1,21 +1,9 @@
-/* This file is part of the KDE project
-   Copyright (C) 2010 Dawit Alemayehu <adawit@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2010 Dawit Alemayehu <adawit@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KPARTS_FILEINFOEXTENSION_H
 #define KPARTS_FILEINFOEXTENSION_H
@@ -24,14 +12,14 @@
 
 #include <KFileItem>
 #include <QObject>
+#include <memory>
 
 class KFileItemList;
-class FileInfoExtensionPrivate;
 
 namespace KParts
 {
-
 class ReadOnlyPart;
+class FileInfoExtensionPrivate;
 
 /**
  * @class FileInfoExtension fileinfoextension.h <KParts/FileInfoExtension>
@@ -52,15 +40,14 @@ class KPARTS_EXPORT FileInfoExtension : public QObject
     Q_OBJECT
 
 public:
-
     /**
      * Supported file information retrieval modes.
      * @see QueryModes
      */
-    enum QueryMode  {
-        None = 0x00,              /*!< Querying for file information is NOT possible */
-        AllItems = 0x01,          /*!< Retrieve or can retrieve file information for all items.*/
-        SelectedItems = 0x02      /*!< Retrieve or can retrieve file information for selected items.*/
+    enum QueryMode {
+        None = 0x00, /*!< Querying for file information is NOT possible */
+        AllItems = 0x01, /*!< Retrieve or can retrieve file information for all items.*/
+        SelectedItems = 0x02, /*!< Retrieve or can retrieve file information for selected items.*/
     };
 
     /**
@@ -72,7 +59,7 @@ public:
     explicit FileInfoExtension(KParts::ReadOnlyPart *parent);
 
     /*! Destructor */
-    virtual ~FileInfoExtension();
+    ~FileInfoExtension() override;
 
     /**
      * Queries @p obj for a child object which inherits from this class.
@@ -104,11 +91,11 @@ public:
     virtual KFileItemList queryFor(QueryMode mode) const = 0;
 
 private:
-    FileInfoExtensionPrivate *const d;
+    std::unique_ptr<FileInfoExtensionPrivate> const d;
 };
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(FileInfoExtension::QueryModes)
+
 }
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(KParts::FileInfoExtension::QueryModes)
-
 #endif /* KPARTS_FILEINFOEXTENSION_H */
