@@ -86,7 +86,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
@@ -248,7 +248,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55d00
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56200
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -258,7 +258,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x55d00
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x56200
 #  endif
 #endif
 
